package GUI;
import ScoreManagement.ScoreManagement;
import ScoreManagement.User;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.util.Scanner;
import javax.swing.DefaultComboBoxModel;

/**
 * Stores the settings and provides an user interface for changing settings
 */
public class Options extends javax.swing.JDialog {
    //Static variables to store the settings in the application context
    static int difficulty = 0;
    static int width = 7;
    static int height = 7;
    static User player1 = null;
    static User player2 = null;
    static boolean controlKeyboard = true;
    static boolean computerasuser = false;

    /**
     * Initialize a new Options window, which allows to change teh settings
     * @param parent The parent window
     * @param modal Whether to show this window as a modal window
     */
    public Options(java.awt.Frame parent, boolean modal) {
        super(parent, modal);
        initComponents();

        // Fill list of players
	fillUserLists();
	fillControls();
    }

    /*
     * Attempt to load the settings from the file options.txt
     */
    public static void Init() {
	File sourceFile = new File("options.txt");
	if (sourceFile.isFile()) {
	    try {
                Scanner sc = new Scanner(sourceFile);
		sc.useDelimiter("[\r\n]{1,2}");
	        difficulty = sc.nextInt();
		width = sc.nextInt();
		height = sc.nextInt();
		player1 = ScoreManagement.getUserByID(sc.nextInt());
		player2 = ScoreManagement.getUserByID(sc.nextInt());
                controlKeyboard = sc.nextBoolean();
		sc.close();
	    } catch (FileNotFoundException ex) {
	    }
	}
        if (player1 == null) player1 = ScoreManagement.getHumanUsers()[0];
    }

    /* Get the difficulty level */
    public static int getDifficulty() { return difficulty; }
    /* Get the game field width in discs */
    public static int getFieldWidth() { return width; }
    /* Get the game field height in discs */
    public static int getFieldHeight() { return height; }
    /* Get whether keyboard controls are enabled */
    public static boolean getControlKeyboard() { return controlKeyboard; }
    /* Get the first user/player */
    public static User getPlayer1() { return player1; }
    /* Get the second user/player or computer user for the selected difficulty level */
    public static User getPlayer2() { 
	if (player2 != null) return player2;
	return ScoreManagement.getUserByDiff(getDifficulty());
    }

    /* Update user dropdown and overview lists */
    private void fillUserLists() {
	User[] users = computerasuser ? ScoreManagement.users : ScoreManagement.getHumanUsers();
	listOfPlayers.setModel(new DefaultComboBoxModel(users));
        comboP1.setModel(new DefaultComboBoxModel(users));
        comboP2.setModel(new DefaultComboBoxModel(users));
    }

    /* Initialize options controls from static variables */
    private void fillControls() {
	comboP1.setSelectedItem(player1);
	comboP2.setSelectedItem(player2);
	selectTwoPlayers.setSelected(player2 != null);
	comboP2.setEnabled(selectTwoPlayers.isSelected());
	switch (width) {
	    case 4: x4.setSelected(true); break;
	    case 5: x5.setSelected(true); break;
	    case 6: x6.setSelected(true); break;
	    case 7: x7.setSelected(true); break;
	    case 8: x8.setSelected(true); break;
	    case 9: x9.setSelected(true); break;
	    case 10: x10.setSelected(true); break;
	}
	switch (height) {
	    case 4: y4.setSelected(true); break;
	    case 5: y5.setSelected(true); break;
	    case 6: y6.setSelected(true); break;
	    case 7: y7.setSelected(true); break;
	    case 8: y8.setSelected(true); break;
	    case 9: y9.setSelected(true); break;
	    case 10: y10.setSelected(true); break;
	}
	switch (difficulty) {
	    case 0: d0.setSelected(true); break;
	    case 1: d1.setSelected(true); break;
	    case 2: d2.setSelected(true); break;
	    case 3: d3.setSelected(true); break;
	    case 4: d4.setSelected(true); break;
	}
        
        radioMouse.setEnabled(!selectTwoPlayers.isSelected());
        radioMouse.setSelected(!controlKeyboard);
        radioKeyboard.setSelected(controlKeyboard);
        
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        Horizontal = new javax.swing.ButtonGroup();
        Vertical = new javax.swing.ButtonGroup();
        Difficulty = new javax.swing.ButtonGroup();
        nofPlayers = new javax.swing.ButtonGroup();
        controls = new javax.swing.ButtonGroup();
        panelMain = new javax.swing.JPanel();
        panelOptions = new javax.swing.JPanel();
        panelPlayers = new javax.swing.JPanel();
        comboP1 = new javax.swing.JComboBox();
        comboP2 = new javax.swing.JComboBox();
        lableP1 = new javax.swing.JLabel();
        lableP2 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        panelManagePlayers = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        jScrollPane1 = new javax.swing.JScrollPane();
        listOfPlayers = new javax.swing.JList();
        bNewPlayer = new javax.swing.JButton();
        jNewPlayer = new javax.swing.JTextField();
        panelDifficulty = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        d0 = new javax.swing.JRadioButton();
        d1 = new javax.swing.JRadioButton();
        d2 = new javax.swing.JRadioButton();
        d3 = new javax.swing.JRadioButton();
        d4 = new javax.swing.JRadioButton();
        panelGridSize = new javax.swing.JPanel();
        lableGridTitle = new javax.swing.JLabel();
        panelVertical = new javax.swing.JPanel();
        y4 = new javax.swing.JRadioButton();
        y5 = new javax.swing.JRadioButton();
        y6 = new javax.swing.JRadioButton();
        y7 = new javax.swing.JRadioButton();
        y8 = new javax.swing.JRadioButton();
        y9 = new javax.swing.JRadioButton();
        y10 = new javax.swing.JRadioButton();
        panelHorizontal = new javax.swing.JPanel();
        x4 = new javax.swing.JRadioButton();
        x5 = new javax.swing.JRadioButton();
        x6 = new javax.swing.JRadioButton();
        x7 = new javax.swing.JRadioButton();
        x8 = new javax.swing.JRadioButton();
        x9 = new javax.swing.JRadioButton();
        x10 = new javax.swing.JRadioButton();
        panelControls = new javax.swing.JPanel();
        bSave = new javax.swing.JButton();
        bRestore = new javax.swing.JButton();
        bName = new javax.swing.JButton();
        panelNoPlayers = new javax.swing.JPanel();
        jLabel4 = new javax.swing.JLabel();
        selectOnePlayer = new javax.swing.JRadioButton();
        selectTwoPlayers = new javax.swing.JRadioButton();
        jPanel1 = new javax.swing.JPanel();
        jLabel5 = new javax.swing.JLabel();
        radioKeyboard = new javax.swing.JRadioButton();
        radioMouse = new javax.swing.JRadioButton();
        labelTitle = new javax.swing.JLabel();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance().getContext().getResourceMap(Options.class);
        setBackground(resourceMap.getColor("Form.background")); // NOI18N
        setName("Form"); // NOI18N

        panelMain.setBackground(resourceMap.getColor("panelMain.background")); // NOI18N
        panelMain.setName("panelMain"); // NOI18N

        panelOptions.setBackground(resourceMap.getColor("panelOptions.background")); // NOI18N
        panelOptions.setName("panelOptions"); // NOI18N

        panelPlayers.setBackground(resourceMap.getColor("panelPlayers.background")); // NOI18N
        panelPlayers.setName("panelPlayers"); // NOI18N

        comboP1.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        comboP1.setName("comboP1"); // NOI18N

        comboP2.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Item 1", "Item 2", "Item 3", "Item 4" }));
        comboP2.setEnabled(false);
        comboP2.setName("comboP2"); // NOI18N

        lableP1.setText(resourceMap.getString("lableP1.text")); // NOI18N
        lableP1.setName("lableP1"); // NOI18N

        lableP2.setText(resourceMap.getString("lableP2.text")); // NOI18N
        lableP2.setName("lableP2"); // NOI18N

        jLabel3.setFont(resourceMap.getFont("jLabel3.font")); // NOI18N
        jLabel3.setText(resourceMap.getString("jLabel3.text")); // NOI18N
        jLabel3.setName("jLabel3"); // NOI18N

        javax.swing.GroupLayout panelPlayersLayout = new javax.swing.GroupLayout(panelPlayers);
        panelPlayers.setLayout(panelPlayersLayout);
        panelPlayersLayout.setHorizontalGroup(
            panelPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelPlayersLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panelPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(panelPlayersLayout.createSequentialGroup()
                        .addComponent(lableP2)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 270, Short.MAX_VALUE)
                        .addComponent(comboP2, javax.swing.GroupLayout.PREFERRED_SIZE, 136, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelPlayersLayout.createSequentialGroup()
                        .addComponent(lableP1)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 270, Short.MAX_VALUE)
                        .addComponent(comboP1, javax.swing.GroupLayout.PREFERRED_SIZE, 136, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addComponent(jLabel3, javax.swing.GroupLayout.Alignment.TRAILING))
                .addContainerGap())
        );
        panelPlayersLayout.setVerticalGroup(
            panelPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelPlayersLayout.createSequentialGroup()
                .addGap(12, 12, 12)
                .addComponent(jLabel3)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(panelPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(comboP1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(lableP1))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(panelPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(lableP2)
                    .addComponent(comboP2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap())
        );

        panelManagePlayers.setBackground(resourceMap.getColor("panelManagePlayers.background")); // NOI18N
        panelManagePlayers.setName("panelManagePlayers"); // NOI18N

        jLabel2.setFont(new java.awt.Font("Tahoma", 1, 14)); // NOI18N
        jLabel2.setText(resourceMap.getString("jLabel2.text")); // NOI18N
        jLabel2.setName("jLabel2"); // NOI18N

        jScrollPane1.setName("jScrollPane1"); // NOI18N

        listOfPlayers.setModel(new javax.swing.AbstractListModel() {
            String[] strings = { "Ruben", "Ivo", "Romain", "Twan", "Joris", "Erik", "Nicola" };
            public int getSize() { return strings.length; }
            public Object getElementAt(int i) { return strings[i]; }
        });
        listOfPlayers.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        listOfPlayers.setName("listOfPlayers"); // NOI18N
        jScrollPane1.setViewportView(listOfPlayers);

        bNewPlayer.setText(resourceMap.getString("bNewPlayer.text")); // NOI18N
        bNewPlayer.setName("bNewPlayer"); // NOI18N
        bNewPlayer.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                bNewPlayerActionPerformed(evt);
            }
        });

        jNewPlayer.setText(resourceMap.getString("jNewPlayer.text")); // NOI18N
        jNewPlayer.setName("jNewPlayer"); // NOI18N

        javax.swing.GroupLayout panelManagePlayersLayout = new javax.swing.GroupLayout(panelManagePlayers);
        panelManagePlayers.setLayout(panelManagePlayersLayout);
        panelManagePlayersLayout.setHorizontalGroup(
            panelManagePlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelManagePlayersLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panelManagePlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jScrollPane1, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 449, Short.MAX_VALUE)
                    .addComponent(jLabel2, javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelManagePlayersLayout.createSequentialGroup()
                        .addComponent(jNewPlayer, javax.swing.GroupLayout.PREFERRED_SIZE, 118, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(bNewPlayer)))
                .addContainerGap())
        );
        panelManagePlayersLayout.setVerticalGroup(
            panelManagePlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelManagePlayersLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel2)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panelManagePlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(bNewPlayer)
                    .addComponent(jNewPlayer, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        panelDifficulty.setBackground(resourceMap.getColor("panelDifficulty.background")); // NOI18N
        panelDifficulty.setName("panelDifficulty"); // NOI18N

        jLabel1.setFont(resourceMap.getFont("jLabel1.font")); // NOI18N
        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N

        Difficulty.add(d0);
        d0.setText(resourceMap.getString("d0.text")); // NOI18N
        d0.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        d0.setName("d0"); // NOI18N

        Difficulty.add(d1);
        d1.setText(resourceMap.getString("d1.text")); // NOI18N
        d1.setToolTipText(resourceMap.getString("d1.toolTipText")); // NOI18N
        d1.setName("d1"); // NOI18N

        Difficulty.add(d2);
        d2.setText(resourceMap.getString("d2.text")); // NOI18N
        d2.setName("d2"); // NOI18N

        Difficulty.add(d3);
        d3.setSelected(true);
        d3.setText(resourceMap.getString("d3.text")); // NOI18N
        d3.setName("d3"); // NOI18N

        Difficulty.add(d4);
        d4.setText(resourceMap.getString("d4.text")); // NOI18N
        d4.setName("d4"); // NOI18N

        javax.swing.GroupLayout panelDifficultyLayout = new javax.swing.GroupLayout(panelDifficulty);
        panelDifficulty.setLayout(panelDifficultyLayout);
        panelDifficultyLayout.setHorizontalGroup(
            panelDifficultyLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelDifficultyLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panelDifficultyLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(d0, javax.swing.GroupLayout.DEFAULT_SIZE, 393, Short.MAX_VALUE)
                    .addComponent(d1, javax.swing.GroupLayout.DEFAULT_SIZE, 393, Short.MAX_VALUE)
                    .addComponent(d2, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 393, Short.MAX_VALUE)
                    .addComponent(d3, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 393, Short.MAX_VALUE)
                    .addComponent(d4, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 393, Short.MAX_VALUE)
                    .addComponent(jLabel1, javax.swing.GroupLayout.Alignment.TRAILING))
                .addContainerGap())
        );
        panelDifficultyLayout.setVerticalGroup(
            panelDifficultyLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelDifficultyLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel1)
                .addGap(7, 7, 7)
                .addComponent(d0)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(d1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(d2)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(d3)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(d4)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        panelGridSize.setBackground(resourceMap.getColor("panelGridSize.background")); // NOI18N
        panelGridSize.setName("panelGridSize"); // NOI18N

        lableGridTitle.setFont(new java.awt.Font("Tahoma", 1, 14));
        lableGridTitle.setText(resourceMap.getString("lableGridTitle.text")); // NOI18N
        lableGridTitle.setName("lableGridTitle"); // NOI18N

        panelVertical.setName("panelVertical"); // NOI18N

        Vertical.add(y4);
        y4.setText(resourceMap.getString("y4.text")); // NOI18N
        y4.setName("y4"); // NOI18N

        Vertical.add(y5);
        y5.setText(resourceMap.getString("y5.text")); // NOI18N
        y5.setName("y5"); // NOI18N

        Vertical.add(y6);
        y6.setText(resourceMap.getString("y6.text")); // NOI18N
        y6.setName("y6"); // NOI18N

        Vertical.add(y7);
        y7.setSelected(true);
        y7.setText(resourceMap.getString("y7.text")); // NOI18N
        y7.setName("y7"); // NOI18N

        Vertical.add(y8);
        y8.setText(resourceMap.getString("y8.text")); // NOI18N
        y8.setName("y8"); // NOI18N

        Vertical.add(y9);
        y9.setText(resourceMap.getString("y9.text")); // NOI18N
        y9.setName("y9"); // NOI18N

        Vertical.add(y10);
        y10.setText(resourceMap.getString("y10.text")); // NOI18N
        y10.setName("y10"); // NOI18N

        javax.swing.GroupLayout panelVerticalLayout = new javax.swing.GroupLayout(panelVertical);
        panelVertical.setLayout(panelVerticalLayout);
        panelVerticalLayout.setHorizontalGroup(
            panelVerticalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelVerticalLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(panelVerticalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(y5)
                    .addComponent(y9)
                    .addComponent(y8)
                    .addComponent(y7)
                    .addComponent(y6)
                    .addComponent(y10)
                    .addComponent(y4))
                .addContainerGap())
        );
        panelVerticalLayout.setVerticalGroup(
            panelVerticalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelVerticalLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(y10)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(y9)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(y8)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(y7)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(y6)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(y5, javax.swing.GroupLayout.PREFERRED_SIZE, 23, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(y4)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        panelHorizontal.setName("panelHorizontal"); // NOI18N

        Horizontal.add(x4);
        x4.setText(resourceMap.getString("x4.text")); // NOI18N
        x4.setName("x4"); // NOI18N

        Horizontal.add(x5);
        x5.setText(resourceMap.getString("x5.text")); // NOI18N
        x5.setName("x5"); // NOI18N

        Horizontal.add(x6);
        x6.setText(resourceMap.getString("x6.text")); // NOI18N
        x6.setName("x6"); // NOI18N

        Horizontal.add(x7);
        x7.setSelected(true);
        x7.setText(resourceMap.getString("x7.text")); // NOI18N
        x7.setName("x7"); // NOI18N

        Horizontal.add(x8);
        x8.setText(resourceMap.getString("x8.text")); // NOI18N
        x8.setName("x8"); // NOI18N

        Horizontal.add(x9);
        x9.setText(resourceMap.getString("x9.text")); // NOI18N
        x9.setName("x9"); // NOI18N

        Horizontal.add(x10);
        x10.setText(resourceMap.getString("x10.text")); // NOI18N
        x10.setHorizontalAlignment(javax.swing.SwingConstants.TRAILING);
        x10.setName("x10"); // NOI18N
        x10.setVerticalAlignment(javax.swing.SwingConstants.BOTTOM);
        x10.setVerticalTextPosition(javax.swing.SwingConstants.BOTTOM);

        javax.swing.GroupLayout panelHorizontalLayout = new javax.swing.GroupLayout(panelHorizontal);
        panelHorizontal.setLayout(panelHorizontalLayout);
        panelHorizontalLayout.setHorizontalGroup(
            panelHorizontalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelHorizontalLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(x4)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(x5)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(x6)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(x7)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(x8)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(x9)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(x10)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        panelHorizontalLayout.setVerticalGroup(
            panelHorizontalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelHorizontalLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panelHorizontalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(x10)
                    .addGroup(panelHorizontalLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(x4)
                        .addComponent(x5)
                        .addComponent(x6)
                        .addComponent(x7)
                        .addComponent(x8)
                        .addComponent(x9)))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout panelGridSizeLayout = new javax.swing.GroupLayout(panelGridSize);
        panelGridSize.setLayout(panelGridSizeLayout);
        panelGridSizeLayout.setHorizontalGroup(
            panelGridSizeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelGridSizeLayout.createSequentialGroup()
                .addGroup(panelGridSizeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(panelGridSizeLayout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(panelVertical, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 254, Short.MAX_VALUE)
                        .addComponent(lableGridTitle))
                    .addGroup(panelGridSizeLayout.createSequentialGroup()
                        .addGap(56, 56, 56)
                        .addComponent(panelHorizontal, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)))
                .addContainerGap())
        );
        panelGridSizeLayout.setVerticalGroup(
            panelGridSizeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelGridSizeLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panelGridSizeLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(panelVertical, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(lableGridTitle))
                .addGap(7, 7, 7)
                .addComponent(panelHorizontal, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );

        panelControls.setBackground(resourceMap.getColor("panelControls.background")); // NOI18N
        panelControls.setName("panelControls"); // NOI18N

        bSave.setFont(resourceMap.getFont("bSave.font")); // NOI18N
        bSave.setText(resourceMap.getString("bSave.text")); // NOI18N
        bSave.setName("bSave"); // NOI18N
        bSave.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                bSaveActionPerformed(evt);
            }
        });

        bRestore.setFont(resourceMap.getFont("bRestore.font")); // NOI18N
        bRestore.setText(resourceMap.getString("bRestore.text")); // NOI18N
        bRestore.setName("bRestore"); // NOI18N
        bRestore.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                bRestoreActionPerformed(evt);
            }
        });

        bName.setText(resourceMap.getString("bCancel.text")); // NOI18N
        bName.setName("bCancel"); // NOI18N
        bName.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                bNameActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout panelControlsLayout = new javax.swing.GroupLayout(panelControls);
        panelControls.setLayout(panelControlsLayout);
        panelControlsLayout.setHorizontalGroup(
            panelControlsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelControlsLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(bSave)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(bRestore)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(bName)
                .addContainerGap(126, Short.MAX_VALUE))
        );
        panelControlsLayout.setVerticalGroup(
            panelControlsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelControlsLayout.createSequentialGroup()
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(panelControlsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(bSave)
                    .addComponent(bRestore)
                    .addComponent(bName))
                .addContainerGap())
        );

        panelNoPlayers.setBackground(resourceMap.getColor("panelNoPlayers.background")); // NOI18N
        panelNoPlayers.setName("panelNoPlayers"); // NOI18N

        jLabel4.setFont(resourceMap.getFont("jLabel4.font")); // NOI18N
        jLabel4.setText(resourceMap.getString("jLabel4.text")); // NOI18N
        jLabel4.setName("jLabel4"); // NOI18N

        selectOnePlayer.setBackground(resourceMap.getColor("selectOnePlayer.background")); // NOI18N
        nofPlayers.add(selectOnePlayer);
        selectOnePlayer.setSelected(true);
        selectOnePlayer.setText(resourceMap.getString("selectOnePlayer.text")); // NOI18N
        selectOnePlayer.setName("selectOnePlayer"); // NOI18N
        selectOnePlayer.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                selectTwoPlayersActionPerformed(evt);
            }
        });

        selectTwoPlayers.setBackground(resourceMap.getColor("selectTwoPlayers.background")); // NOI18N
        nofPlayers.add(selectTwoPlayers);
        selectTwoPlayers.setText(resourceMap.getString("selectTwoPlayers.text")); // NOI18N
        selectTwoPlayers.setName("selectTwoPlayers"); // NOI18N
        selectTwoPlayers.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                selectTwoPlayersActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout panelNoPlayersLayout = new javax.swing.GroupLayout(panelNoPlayers);
        panelNoPlayers.setLayout(panelNoPlayersLayout);
        panelNoPlayersLayout.setHorizontalGroup(
            panelNoPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelNoPlayersLayout.createSequentialGroup()
                .addContainerGap(332, Short.MAX_VALUE)
                .addComponent(jLabel4)
                .addContainerGap())
            .addGroup(panelNoPlayersLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(selectOnePlayer)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(selectTwoPlayers)
                .addContainerGap(299, Short.MAX_VALUE))
        );
        panelNoPlayersLayout.setVerticalGroup(
            panelNoPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelNoPlayersLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel4)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(panelNoPlayersLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(selectOnePlayer)
                    .addComponent(selectTwoPlayers))
                .addContainerGap(17, Short.MAX_VALUE))
        );

        jPanel1.setBackground(resourceMap.getColor("jPanel1.background")); // NOI18N
        jPanel1.setName("jPanel1"); // NOI18N

        jLabel5.setFont(resourceMap.getFont("jLabel5.font")); // NOI18N
        jLabel5.setText(resourceMap.getString("jLabel5.text")); // NOI18N
        jLabel5.setName("jLabel5"); // NOI18N

        radioKeyboard.setBackground(resourceMap.getColor("radioKeyboard.background")); // NOI18N
        controls.add(radioKeyboard);
        radioKeyboard.setText(resourceMap.getString("radioKeyboard.text")); // NOI18N
        radioKeyboard.setName("radioKeyboard"); // NOI18N

        radioMouse.setBackground(resourceMap.getColor("radioMouse.background")); // NOI18N
        controls.add(radioMouse);
        radioMouse.setText(resourceMap.getString("radioMouse.text")); // NOI18N
        radioMouse.setName("radioMouse"); // NOI18N

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGap(15, 15, 15)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(radioMouse)
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addComponent(radioKeyboard)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 262, Short.MAX_VALUE)
                        .addComponent(jLabel5)))
                .addContainerGap())
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addContainerGap()
                        .addComponent(jLabel5))
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addGap(20, 20, 20)
                        .addComponent(radioKeyboard)))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(radioMouse)
                .addContainerGap(13, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout panelOptionsLayout = new javax.swing.GroupLayout(panelOptions);
        panelOptions.setLayout(panelOptionsLayout);
        panelOptionsLayout.setHorizontalGroup(
            panelOptionsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, panelOptionsLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(panelOptionsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jPanel1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panelNoPlayers, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panelPlayers, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panelManagePlayers, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(panelOptionsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(panelControls, 0, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panelDifficulty, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(panelGridSize, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap())
        );
        panelOptionsLayout.setVerticalGroup(
            panelOptionsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelOptionsLayout.createSequentialGroup()
                .addGap(15, 15, 15)
                .addGroup(panelOptionsLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addGroup(panelOptionsLayout.createSequentialGroup()
                        .addComponent(panelGridSize, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(panelDifficulty, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(panelControls, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(panelOptionsLayout.createSequentialGroup()
                        .addComponent(panelNoPlayers, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(panelPlayers, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(panelManagePlayers, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(jPanel1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
                .addContainerGap(48, Short.MAX_VALUE))
        );

        labelTitle.setFont(resourceMap.getFont("labelTitle.font")); // NOI18N
        labelTitle.setForeground(resourceMap.getColor("labelTitle.foreground")); // NOI18N
        labelTitle.setText(resourceMap.getString("labelTitle.text")); // NOI18N
        labelTitle.setName("labelTitle"); // NOI18N

        javax.swing.GroupLayout panelMainLayout = new javax.swing.GroupLayout(panelMain);
        panelMain.setLayout(panelMainLayout);
        panelMainLayout.setHorizontalGroup(
            panelMainLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelMainLayout.createSequentialGroup()
                .addContainerGap(802, Short.MAX_VALUE)
                .addComponent(labelTitle)
                .addContainerGap())
            .addComponent(panelOptions, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
        );
        panelMainLayout.setVerticalGroup(
            panelMainLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(panelMainLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(labelTitle)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(panelOptions, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(panelMain, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(panelMain, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    /* Number of players has changed, enable/disable other controls accordingly */
    private void selectTwoPlayersActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_selectTwoPlayersActionPerformed
	comboP2.setEnabled(selectTwoPlayers.isSelected());
        radioMouse.setEnabled(!selectTwoPlayers.isSelected());
        if (!radioMouse.isEnabled() && radioMouse.isSelected()) {
            radioMouse.setSelected(false);
            radioKeyboard.setSelected(true);
        }
    }//GEN-LAST:event_selectTwoPlayersActionPerformed

    /* Restore default settings and update controls */
    private void bRestoreActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bRestoreActionPerformed
	difficulty = 0;
	width = 7;
	height = 7;
	player1 = ScoreManagement.getHumanUsers()[0];
	player2 = null;
        controlKeyboard = true;
	fillControls();
    }//GEN-LAST:event_bRestoreActionPerformed

    /* Store the settings to the application context static variables and write to options.txt */
    // Pre:     all settings are defined in the GUI
    // Post:    all settings are saved into the static variables
    private void bSaveActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bSaveActionPerformed
	if (y4.isSelected()) height = 4;
	if (y5.isSelected()) height = 5;
	if (y6.isSelected()) height = 6;
	if (y7.isSelected()) height = 7;
	if (y8.isSelected()) height = 8;
	if (y9.isSelected()) height = 9;
	if (y10.isSelected()) height = 10;
	if (x4.isSelected()) width = 4;
	if (x5.isSelected()) width = 5;
	if (x6.isSelected()) width = 6;
	if (x7.isSelected()) width = 7;
	if (x8.isSelected()) width = 8;
	if (x9.isSelected()) width = 9;
	if (x10.isSelected()) width = 10;
	if (d0.isSelected()) difficulty = 0;
	if (d1.isSelected()) difficulty = 1;
	if (d2.isSelected()) difficulty = 2;
	if (d3.isSelected()) difficulty = 3;
	if (d4.isSelected()) difficulty = 4;
        controlKeyboard = radioKeyboard.isSelected();
        
	player1 = (User)comboP1.getSelectedItem();
	player2 = selectOnePlayer.isSelected() ? null : (User)comboP2.getSelectedItem();
	try {
	    File sourceFile = new File("options.txt");
	    PrintWriter pw = new PrintWriter(sourceFile);
	    pw.println(difficulty);
	    pw.println(width);
	    pw.println(height);
	    pw.println(player1 == null ? -1 : player1.getID());
	    pw.println(player2 == null ? -1 : player2.getID());
            pw.println(controlKeyboard);
	    pw.close();
	} catch (FileNotFoundException ex) {
	}
	setVisible(false);
	dispose();
    }//GEN-LAST:event_bSaveActionPerformed

    /* Add a new player to the player list and update the user lists */
    private void bNewPlayerActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bNewPlayerActionPerformed
	ScoreManagement.addUser(jNewPlayer.getText());
	fillUserLists();
    }//GEN-LAST:event_bNewPlayerActionPerformed

    /* Cancel button, don't save settings and close window */
    private void bNameActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bNameActionPerformed
	setVisible(false);
	dispose();
    }//GEN-LAST:event_bNameActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.ButtonGroup Difficulty;
    private javax.swing.ButtonGroup Horizontal;
    private javax.swing.ButtonGroup Vertical;
    private javax.swing.JButton bName;
    private javax.swing.JButton bNewPlayer;
    private javax.swing.JButton bRestore;
    private javax.swing.JButton bSave;
    private javax.swing.JComboBox comboP1;
    private javax.swing.JComboBox comboP2;
    private javax.swing.ButtonGroup controls;
    private javax.swing.JRadioButton d0;
    private javax.swing.JRadioButton d1;
    private javax.swing.JRadioButton d2;
    private javax.swing.JRadioButton d3;
    private javax.swing.JRadioButton d4;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JTextField jNewPlayer;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JLabel labelTitle;
    private javax.swing.JLabel lableGridTitle;
    private javax.swing.JLabel lableP1;
    private javax.swing.JLabel lableP2;
    private javax.swing.JList listOfPlayers;
    private javax.swing.ButtonGroup nofPlayers;
    private javax.swing.JPanel panelControls;
    private javax.swing.JPanel panelDifficulty;
    private javax.swing.JPanel panelGridSize;
    private javax.swing.JPanel panelHorizontal;
    private javax.swing.JPanel panelMain;
    private javax.swing.JPanel panelManagePlayers;
    private javax.swing.JPanel panelNoPlayers;
    private javax.swing.JPanel panelOptions;
    private javax.swing.JPanel panelPlayers;
    private javax.swing.JPanel panelVertical;
    private javax.swing.JRadioButton radioKeyboard;
    private javax.swing.JRadioButton radioMouse;
    private javax.swing.JRadioButton selectOnePlayer;
    private javax.swing.JRadioButton selectTwoPlayers;
    private javax.swing.JRadioButton x10;
    private javax.swing.JRadioButton x4;
    private javax.swing.JRadioButton x5;
    private javax.swing.JRadioButton x6;
    private javax.swing.JRadioButton x7;
    private javax.swing.JRadioButton x8;
    private javax.swing.JRadioButton x9;
    private javax.swing.JRadioButton y10;
    private javax.swing.JRadioButton y4;
    private javax.swing.JRadioButton y5;
    private javax.swing.JRadioButton y6;
    private javax.swing.JRadioButton y7;
    private javax.swing.JRadioButton y8;
    private javax.swing.JRadioButton y9;
    // End of variables declaration//GEN-END:variables
}
