/*
 * Scoremanagement keeps track of the user dataabse and the games database. It 
 * can add games to the score file and it can add users to the user database.
 * 
 * Scoremanagement provides the needed arrays for the calculation of the
 * high scores
 */
package ScoreManagement;

import java.util.Scanner;
import java.io.*;
import java.util.Calendar;
import java.text.SimpleDateFormat;
import java.util.Arrays;

/**
 * Handles management of (high)scores/game history
 */
public class ScoreManagement {
    // The arrays which contain all the users and all GameResults
    public static User users[];
    public static GameResult games[];
    
    /* Loads the user list and game results from the data files */
    // Pre:     True
    // Post:    readUserFile() and readScoresFile() are executed
    public static void Init() {
        readUserFile();
        readScoresFile();
    }

    // Pre:     users[] is defined, but not yet initialized
    // Post:    All the users are stored into the array users
    // This method reads all the users from users.txt into the array 'users'
    // The structure of users.txt is defined in the documentation
    private static void readUserFile() {
        // Variables
        try {
            File sourceFile = new File("user.txt");
	    if (!sourceFile.isFile()) {
		PrintWriter pw = new PrintWriter(sourceFile);
                pw.println(6);
		pw.println("Very easy");
		pw.println(0);
		pw.println("Easy");
		pw.println(1);
		pw.println("Medium");
		pw.println(2);
		pw.println("Hard");
		pw.println(3);
		pw.println("Expert");
		pw.println(4);
                pw.println("John Doe");
                pw.println(-1);
                pw.close();
	    }
            Scanner sc = new Scanner(sourceFile);
	    sc.useDelimiter("[\r\n]{1,2}");

            // Initialize the array
            // Length of array is stored in the first rule of user.txt
            int arrayLength = sc.nextInt();
            users = new User[arrayLength];

            // For each user, make a new object
            for (int i = 0; i != arrayLength; i++) {
                User tmpUser = new User(i, sc.next(), sc.nextInt());
                users[i] = tmpUser;
            }

	    sc.close();
        } catch (FileNotFoundException e) {
            System.out.println("Could not open file due to");
            System.out.println(e);
        }
    }

    // Pre:     scores.txt must exist
    //          games[] is defined, but not yet initialized
    // Post:    All the scores.txt are stored into the array 'games'
    // This method reads all the score information from scores.txt into the
    // array 'games'. The structure of scores.txt is defined
    // in the documentation
    private static void readScoresFile() {
        try {
            File sourceFile = new File("scores.txt");
            Scanner sc = new Scanner(sourceFile);

            // Initialize the array
            // Length of array is stored in the first rule of user.txt
            int arrayLength = sc.nextInt();
            games = new GameResult[arrayLength];

            // For each user, make a new object
            for (int i = 0; i != arrayLength; i++) {
                // Stores User1, User2, Winner, Date, Moves
                GameResult tmpGame = new GameResult(getUserByID(sc.nextInt()),
                        getUserByID(sc.nextInt()), getUserByID(sc.nextInt()),
                        sc.next(), sc.nextInt());
                games[i] = tmpGame;
            }
        } catch (FileNotFoundException e) {
	    games = new GameResult[0];
        }
    }

    // Pre:     game is a valid argument which contains an object of type
    //          GameResult
    // Post:    highscores.txt is updated with the new Game Result and
    //          games[] is updated
    /* This method stores the new Game Result into the Score Database */
    public static void addGame(GameResult game) {
        // First, update the array
	games = Arrays.copyOf(games, games.length + 1);
        // Add the game array
        games[games.length - 1] = game;

        // Write the file
        PrintWriter pw;
        File targetFile;

        try {
            targetFile = new File("scores.txt");
            pw = new PrintWriter(targetFile);

            // Put the total length of the array in the first rule
            pw.println(games.length);

            for (int i = 0; i != games.length; i++) {
                pw.println(games[i].player1.getID());
                pw.println(games[i].player2.getID());
                pw.println(games[i].winner == null ? -1 : games[i].winner.getID());
                pw.println(games[i].date);
                pw.println(games[i].moves);
            }
            
            pw.close();
        } catch (FileNotFoundException e) {
            System.out.println("Could not open file due to");
            System.out.println(e);
        }
    }

    // Pre:     true
    // Post:    Returns an array (gamesDay[]) containing all references 
    //          to gameResult objects which contain a date is 
    //          equal to the current date.
    /* Gets a list of all game results for which the date equals today's date */
    public static GameResult[] getGamesDay() {
        // Make a string with the time of today
        Calendar date = Calendar.getInstance();
        SimpleDateFormat dateformatter = new SimpleDateFormat("dd-MM-yyyy");
        String strToday;
        strToday = dateformatter.format(date.getTime());

        // Create a new array with only the game results of today
        GameResult gamesDay[] = new GameResult[games.length];
        int count = 0;

        // copy only the values of today
        for (int i = 0; i != games.length; i++) {
            if (games[i].date.equals(strToday)) {
                gamesDay[count] = games[i];
                count++;
            }
        }

        // Array is probably to long, create a new one which is shorter
        GameResult returnGamesDay[] = new GameResult[count];

        // Copy array
        for (int i = 0; i != returnGamesDay.length; i++) {
            returnGamesDay[i] = gamesDay[i];
        }

        return returnGamesDay;
    }
    
    // Pre:     true
    // Post:    Returns an array (gamesWeek[]) containing all references to 
    //          gameResult objects which contain a date that lies
    //          within the domain (current day – 6, current day).
    /* Gets a list of all game results for which were played this week */
    public static GameResult[] getGamesWeek() {
        // Make a new object for the 7 dates
        String dates[] = new String[7];
        Calendar date = Calendar.getInstance();
        SimpleDateFormat dateformatter = new SimpleDateFormat("dd-MM-yyyy");
        
        // Store the 7 dates
        for (int i = 0; i != dates.length; i++) {
            dates[i] = dateformatter.format(date.getTime());
            date.add(Calendar.DATE, -1);
        }        
        
        // Create a new array with only the game results of today
        GameResult gamesWeek[] = new GameResult[games.length];
        int count = 0;

        // copy only the values which are in the array
        for (int i = 0; i != games.length; i++) {
            for (int j = 0; j != dates.length; j++) {
                if (games[i].date.equals(dates[j])) {
                    gamesWeek[count] = games[i];
                    count++;
                }
            }
        }

        // Array is probably to long, create a new one which is shorter
        GameResult returnGamesWeek[] = new GameResult[count];

        // Copy array
        for (int i = 0; i != returnGamesWeek.length; i++) {
            returnGamesWeek[i] = gamesWeek[i];
        }

        return returnGamesWeek;
    }
    
    // Pre:     users is defined
    // Post:    returns an array, for every item i holds:
    //          array[i].isComputer == false
    /* Gets a list of all human users in the database */
    public static User[] getHumanUsers() {
        // We create a new array which contains only the human users
        User h[] = new User[users.length];
        
        // Copy the ones which are users
        int count = 0;
        for (int i = 0; i != h.length; i++) {
            if (!users[i].isComputer()) {
                h[count] = users[i];
                count++;
            }
        }
        
        // Array is probably to long, create a new one which is shorter
        User returnUsers[] = new User[count];

        // Copy array
        for (int i = 0; i != returnUsers.length; i++) {
            returnUsers[i] = h[i];
        }

        return returnUsers;        

    }

    // Pre:     users is defined
    // Post:    returns an array, for every item i holds:
    //          array[i].isComputer == true
    /* Gets a list of all computer users in the database */
    public static User[] getComputerUsers() {
        // We create a new array which contains only the human users
        User h[] = new User[users.length];
        
        // Copy the ones which are users
        int count = 0;
        for (int i = 0; i != h.length; i++) {
            if (users[i].isComputer()) {
                h[count] = users[i];
                count++;
            }
        }
        
        // Array is probably to long, create a new one which is shorter
        User returnUsers[] = new User[count];

        // Copy array
        for (int i = 0; i != returnUsers.length; i++) {
            returnUsers[i] = h[i];
        }

        return returnUsers;        
    }
    
    
    // Pre:     user is an appropriate User object
    // Post:    The user is added to the User database user.txt and 
    //          is added to users[]
    /**
     * Add a new user to the database
     * @param user Name of the new user
     */
    public static void addUser(String user) {
        // First, update the array
        User h[] = new User[users.length];

        // Copy
        for (int i = 0; i != users.length; i++) {
            h[i] = users[i];
        }

        users = new User[users.length + 1];
        for (int i = 0; i != h.length; i++) {
            users[i] = h[i];
        }

        // Create the new user object
        User usr = new User(users.length - 1, user, -1);
        users[users.length - 1] = usr;

        // Write the file
        PrintWriter pw;
        File targetFile;

        try {
            targetFile = new File("user.txt");
            pw = new PrintWriter(targetFile);

            // Put the total length of the array in the first rule
            pw.println(users.length);

            for (int i = 0; i != users.length; i++) {
                pw.println(users[i].getName());
                pw.println(users[i].getDif());
            }
            pw.close();

        } catch (FileNotFoundException e) {
            System.out.println("Could not open file due to");
            System.out.println(e);
        }
    }

    // Pre:     true;
    // Post:    returns the reference to the User object in users[]
    //          where ident == ID
    //          returns null if there is no user where ident == ID
    /**
     * Gets an User instance for the given ID, or null if no such user exists
     * @param ident The ID number of the user
     * @return An User instance, or null if the user was not found
     */
    public static User getUserByID(int ident) {
        for (int i = 0; i != users.length; i++) {
            if (users[i].getID() == ident) {
                return users[i];
            }
        }
        return null;
    }

    /**
     * Gets an User instance for the computer player with the specified difficulty level
     * @param diff Difficulty level to look for
     * @return User instance for a computer player, or null if the user was not found
     */
    public static User getUserByDiff(int diff) {
	for (User u : users) if (u.getDif() == diff) return u;
        return null;
    }
}
